from setuptools import setup
from distutils.core import setup
setup(
    name = "sentiic",
    version= "0.0.3",
    description= " Sentimental Analysis From Social Media",
    author="DUMPA NAVEEN KUMAR REDDY",
    author_email="naveenkumarreddydumpa@gmail.com",
    py_modules=["rdvac6"],
    package_dir={"":"src"},
    include_package_data=True,
)
